Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(28)

Unified Diff: ui/latency/latency_info.h

Issue 2788893004: Renaming gpu swap buffer callbacks and the screenshot latency component. (Closed)
Patch Set: Updating android compositor Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/renderer_host/render_widget_host_impl.cc ('k') | ui/latency/latency_info.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/latency/latency_info.h
diff --git a/ui/latency/latency_info.h b/ui/latency/latency_info.h
index 1fe89f7f30e6ea8f54d05d9c224dfa897db5570b..f34e09ac8ea47f67560820c47c1ed3e261576b0e 100644
--- a/ui/latency/latency_info.h
+++ b/ui/latency/latency_info.h
@@ -68,9 +68,9 @@ enum LatencyComponentType {
INPUT_EVENT_LATENCY_FORWARD_SCROLL_UPDATE_TO_MAIN_COMPONENT,
// Timestamp when the event's ack is received by the RWH.
INPUT_EVENT_LATENCY_ACK_RWH_COMPONENT,
// Frame number when a window snapshot was requested. The snapshot
// is taken when the rendering results actually reach the screen.
- WINDOW_SNAPSHOT_FRAME_NUMBER_COMPONENT,
+ BROWSER_SNAPSHOT_FRAME_NUMBER_COMPONENT,
// Timestamp when a tab is requested to be shown.
TAB_SHOW_COMPONENT,
// Timestamp when the frame is swapped in renderer.
@@ -68,9 +68,9 @@ enum LatencyComponentType {
// Timestamp when the event's ack is received by the RWH.
INPUT_EVENT_LATENCY_ACK_RWH_COMPONENT,
- // Frame number when a window snapshot was requested. The snapshot
+ // Frame number when a browser snapshot was requested. The snapshot
// is taken when the rendering results actually reach the screen.
« no previous file with comments | « content/browser/renderer_host/render_widget_host_impl.cc ('k') | ui/latency/latency_info.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698